@@ -348,6 +348,7 @@ pub struct CrawlingSettings {
 	pub max_response_size:         CBytes,
 	pub delay:                     CDuration,
 	pub delay_jitter:              CDuration,
+	pub status_timeout:            CDuration,
 	pub load_timeout:              CDuration,
 	pub job_soft_timeout:          CDuration,
 	pub job_hard_timeout:          CDuration,
@@ -375,8 +376,9 @@ impl Default for CrawlingSettings {
 			delay_jitter:              CDuration::from_millis(1000),
 			job_hard_timeout:          CDuration::from_secs(60),
 			job_soft_timeout:          CDuration::from_secs(30),
+			status_timeout:            CDuration::from_secs(5),
 			load_timeout:              CDuration::from_secs(10),
-			user_agent:                Some(String::from("crusty-core/0.62.0")),
+			user_agent:                Some(String::from("crusty-core/0.64.0")),
 			compression:               true,
 			custom_headers:            HashMap::new(),
 			max_response_size:         CBytes(1024 * 1024 * 2),
